@@ -1,5 +1,6 @@
 
-void fam_bypass(mongoc_collection_t *collection)
+void
+fam_bypass (mongoc_collection_t *collection)
 {
    mongoc_find_and_modify_opts_t *opts;
    bson_t reply;
@@ -15,25 +16,25 @@ void fam_bypass(mongoc_collection_t *collection)
    BSON_APPEND_UTF8 (&query, "profession", "Football player");
 
    /* Bump his age */
-   update = BCON_NEW ("$inc", "{",
-      "age", BCON_INT32 (1),
-   "}");
+   update = BCON_NEW ("$inc", "{", "age", BCON_INT32 (1), "}");
 
    opts = mongoc_find_and_modify_opts_new ();
    mongoc_find_and_modify_opts_set_update (opts, update);
    /* He can still play, even though he is pretty old. */
    mongoc_find_and_modify_opts_set_bypass_document_validation (opts, true);
 
-   success = mongoc_collection_find_and_modify_with_opts (collection, &query, opts, &reply, &error);
+   success = mongoc_collection_find_and_modify_with_opts (
+      collection, &query, opts, &reply, &error);
 
    if (success) {
       char *str;
 
-      str = bson_as_json (&reply, NULL);
+      str = bson_as_canonical_extended_json (&reply, NULL);
       printf ("%s\n", str);
       bson_free (str);
    } else {
-      fprintf(stderr, "Got error: \"%s\" on line %d\n", error.message, __LINE__);
+      fprintf (
+         stderr, "Got error: \"%s\" on line %d\n", error.message, __LINE__);
    }
 
    bson_destroy (&reply);
@@ -41,4 +42,3 @@ void fam_bypass(mongoc_collection_t *collection)
    bson_destroy (&query);
    mongoc_find_and_modify_opts_destroy (opts);
 }
-
