@@ -1,5 +1,6 @@
 
-void fam_flags(mongoc_collection_t *collection)
+void
+fam_flags (mongoc_collection_t *collection)
 {
    mongoc_find_and_modify_opts_t *opts;
    bson_t reply;
@@ -14,30 +15,32 @@ void fam_flags(mongoc_collection_t *collection)
    BSON_APPEND_UTF8 (&query, "lastname", "Ibrahimovic");
    BSON_APPEND_UTF8 (&query, "profession", "Football player");
    BSON_APPEND_INT32 (&query, "age", 34);
-   BSON_APPEND_INT32 (&query, "goals", (16+35+23+57+16+14+28+84)+(1+6+62));
+   BSON_APPEND_INT32 (
+      &query, "goals", (16 + 35 + 23 + 57 + 16 + 14 + 28 + 84) + (1 + 6 + 62));
 
    /* Add his football position */
-   update = BCON_NEW ("$set", "{",
-      "position", BCON_UTF8 ("striker"),
-   "}");
+   update = BCON_NEW ("$set", "{", "position", BCON_UTF8 ("striker"), "}");
 
    opts = mongoc_find_and_modify_opts_new ();
 
    mongoc_find_and_modify_opts_set_update (opts, update);
 
    /* Create the document if it didn't exist, and return the updated document */
-   mongoc_find_and_modify_opts_set_flags (opts, MONGOC_FIND_AND_MODIFY_UPSERT|MONGOC_FIND_AND_MODIFY_RETURN_NEW);
+   mongoc_find_and_modify_opts_set_flags (
+      opts, MONGOC_FIND_AND_MODIFY_UPSERT | MONGOC_FIND_AND_MODIFY_RETURN_NEW);
 
-   success = mongoc_collection_find_and_modify_with_opts (collection, &query, opts, &reply, &error);
+   success = mongoc_collection_find_and_modify_with_opts (
+      collection, &query, opts, &reply, &error);
 
    if (success) {
       char *str;
 
-      str = bson_as_json (&reply, NULL);
+      str = bson_as_canonical_extended_json (&reply, NULL);
       printf ("%s\n", str);
       bson_free (str);
    } else {
-      fprintf(stderr, "Got error: \"%s\" on line %d\n", error.message, __LINE__);
+      fprintf (
+         stderr, "Got error: \"%s\" on line %d\n", error.message, __LINE__);
    }
 
    bson_destroy (&reply);
@@ -45,4 +48,3 @@ void fam_flags(mongoc_collection_t *collection)
    bson_destroy (&query);
    mongoc_find_and_modify_opts_destroy (opts);
 }
-
