@@ -1,6 +1,6 @@
 import sys
 
-# Should be in EXACT same order as from mongoc-handshake-private.h.
+# Should be in EXACT same order as from src/mongoc/mongoc-handshake-private.h.
 # The values are implicit (so we assume 1st entry is 1 << 0,
 # second entry is 1 << 1 and so on).
 MD_FLAGS = [
@@ -19,6 +19,13 @@ MD_FLAGS = [
     "MONGOC_MD_FLAG_HAVE_WEAK_SYMBOLS",
     "MONGOC_MD_FLAG_NO_AUTOMATIC_GLOBALS",
     "MONGOC_MD_FLAG_ENABLE_SSL_LIBRESSL",
+    "MONGOC_MD_FLAG_ENABLE_SASL_CYRUS",
+    "MONGOC_MD_FLAG_ENABLE_SASL_SSPI",
+    "MONGOC_MD_FLAG_HAVE_SOCKLEN",
+    "MONGOC_MD_FLAG_ENABLE_COMPRESSION",
+    "MONGOC_MD_FLAG_ENABLE_COMPRESSION_SNAPPY",
+    "MONGOC_MD_FLAG_ENABLE_COMPRESSION_ZLIB",
+    "MONGOC_MD_FLAG_ENABLE_SASL_GSSAPI",
 ]
 
 def main():
