@@ -18,28 +18,31 @@
 #include "mongoc-host-list.h"
 #include "mongoc-host-list-private.h"
 #include "mongoc-read-prefs.h"
+#include "mongoc-read-prefs-private.h"
 #include "mongoc-server-description-private.h"
-#include "mongoc-trace.h"
+#include "mongoc-trace-private.h"
 #include "mongoc-uri.h"
 #include "mongoc-util-private.h"
+#include "mongoc-compression-private.h"
 
 #include <stdio.h>
 
 #define ALPHA 0.2
 
 
-static uint8_t kMongocEmptyBson[] = { 5, 0, 0, 0, 0 };
+static uint8_t kMongocEmptyBson[] = {5, 0, 0, 0, 0};
 
-static bson_oid_t kObjectIdZero = { {0} };
+static bson_oid_t kObjectIdZero = {{0}};
 
-static bool _match_tag_set (const mongoc_server_description_t *sd,
-                            bson_iter_t                       *tag_set_iter);
+static bool
+_match_tag_set (const mongoc_server_description_t *sd,
+                bson_iter_t *tag_set_iter);
 
 /* Destroy allocated resources within @description, but don't free it */
 void
 mongoc_server_description_cleanup (mongoc_server_description_t *sd)
 {
-   BSON_ASSERT(sd);
+   BSON_ASSERT (sd);
 
    bson_destroy (&sd->last_is_master);
 }
@@ -49,10 +52,12 @@ mongoc_server_description_cleanup (mongoc_server_description_t *sd)
 void
 mongoc_server_description_reset (mongoc_server_description_t *sd)
 {
-   BSON_ASSERT(sd);
+   BSON_ASSERT (sd);
 
    /* set other fields to default or empty states. election_id is zeroed. */
-   memset (&sd->set_name, 0, sizeof (*sd) - ((char*)&sd->set_name - (char*)sd));
+   memset (
+      &sd->set_name, 0, sizeof (*sd) - ((char *) &sd->set_name - (char *) sd));
+   memset (&sd->error, 0, sizeof sd->error);
    sd->set_name = NULL;
    sd->type = MONGOC_SERVER_UNKNOWN;
 
@@ -87,8 +92,8 @@ mongoc_server_description_reset (mongoc_server_description_t *sd)
  */
 void
 mongoc_server_description_init (mongoc_server_description_t *sd,
-                                const char                  *address,
-                                uint32_t                     id)
+                                const char *address,
+                                uint32_t id)
 {
    ENTRY;
 
@@ -99,14 +104,14 @@ mongoc_server_description_init (mongoc_server_description_t *sd,
 
    sd->id = id;
    sd->type = MONGOC_SERVER_UNKNOWN;
-   sd->round_trip_time = -1;
+   sd->round_trip_time_msec = -1;
 
    sd->set_name = NULL;
    sd->set_version = MONGOC_NO_SET_VERSION;
    sd->current_primary = NULL;
 
-   if (!_mongoc_host_list_from_string(&sd->host, address)) {
-      MONGOC_WARNING("Failed to parse uri for %s", address);
+   if (!_mongoc_host_list_from_string (&sd->host, address)) {
+      MONGOC_WARNING ("Failed to parse uri for %s", address);
       return;
    }
 
@@ -118,11 +123,18 @@ mongoc_server_description_init (mongoc_server_description_t *sd,
    sd->max_msg_size = MONGOC_DEFAULT_MAX_MSG_SIZE;
    sd->max_bson_obj_size = MONGOC_DEFAULT_BSON_OBJ_SIZE;
    sd->max_write_batch_size = MONGOC_DEFAULT_WRITE_BATCH_SIZE;
+   sd->last_write_date_ms = -1;
 
    bson_init_static (&sd->hosts, kMongocEmptyBson, sizeof (kMongocEmptyBson));
-   bson_init_static (&sd->passives, kMongocEmptyBson, sizeof (kMongocEmptyBson));
-   bson_init_static (&sd->arbiters, kMongocEmptyBson, sizeof (kMongocEmptyBson));
+   bson_init_static (
+      &sd->passives, kMongocEmptyBson, sizeof (kMongocEmptyBson));
+   bson_init_static (
+      &sd->arbiters, kMongocEmptyBson, sizeof (kMongocEmptyBson));
    bson_init_static (&sd->tags, kMongocEmptyBson, sizeof (kMongocEmptyBson));
+#ifdef MONGOC_ENABLE_COMPRESSION
+   bson_init_static (
+      &sd->compressors, kMongocEmptyBson, sizeof (kMongocEmptyBson));
+#endif
 
    bson_init (&sd->last_is_master);
 
@@ -150,9 +162,9 @@ mongoc_server_description_destroy (mongoc_server_description_t *description)
 {
    ENTRY;
 
-   mongoc_server_description_cleanup(description);
+   mongoc_server_description_cleanup (description);
 
-   bson_free(description);
+   bson_free (description);
 
    EXIT;
 }
@@ -174,8 +186,8 @@ mongoc_server_description_destroy (mongoc_server_description_t *description)
  *--------------------------------------------------------------------------
  */
 bool
-mongoc_server_description_has_rs_member(mongoc_server_description_t *server,
-                                        const char                  *address)
+mongoc_server_description_has_rs_member (mongoc_server_description_t *server,
+                                         const char *address)
 {
    bson_iter_t member_iter;
    const bson_t *rs_members[3];
@@ -190,7 +202,8 @@ mongoc_server_description_has_rs_member(mongoc_server_description_t *server,
          bson_iter_init (&member_iter, rs_members[i]);
 
          while (bson_iter_next (&member_iter)) {
-            if (strcasecmp (address, bson_iter_utf8 (&member_iter, NULL)) == 0) {
+            if (strcasecmp (address, bson_iter_utf8 (&member_iter, NULL)) ==
+                0) {
                return true;
             }
          }
@@ -214,7 +227,8 @@ mongoc_server_description_has_rs_member(mongoc_server_description_t *server,
  */
 
 bool
-mongoc_server_description_has_set_version (mongoc_server_description_t *description)
+mongoc_server_description_has_set_version (
+   mongoc_server_description_t *description)
 {
    return description->set_version != MONGOC_NO_SET_VERSION;
 }
@@ -233,7 +247,8 @@ mongoc_server_description_has_set_version (mongoc_server_description_t *descript
  */
 
 bool
-mongoc_server_description_has_election_id (mongoc_server_description_t *description)
+mongoc_server_description_has_election_id (
+   mongoc_server_description_t *description)
 {
    return 0 != bson_oid_compare (&description->election_id, &kObjectIdZero);
 }
@@ -252,7 +267,7 @@ mongoc_server_description_has_election_id (mongoc_server_description_t *descript
  */
 
 uint32_t
-mongoc_server_description_id (mongoc_server_description_t *description)
+mongoc_server_description_id (const mongoc_server_description_t *description)
 {
    return description->id;
 }
@@ -265,15 +280,16 @@ mongoc_server_description_id (mongoc_server_description_t *description)
  *      Return a reference to the host associated with this server description.
  *
  * Returns:
- *      A mongoc_host_list_t *, this server description's host.
+ *      This server description's host, a mongoc_host_list_t * you must
+ *      not modify or free.
  *
  *--------------------------------------------------------------------------
  */
 
 mongoc_host_list_t *
-mongoc_server_description_host (mongoc_server_description_t *description)
+mongoc_server_description_host (const mongoc_server_description_t *description)
 {
-   return &description->host;
+   return &((mongoc_server_description_t *) description)->host;
 }
 
 /*
@@ -291,9 +307,10 @@ mongoc_server_description_host (mongoc_server_description_t *description)
  */
 
 int64_t
-mongoc_server_description_round_trip_time (mongoc_server_description_t *description)
+mongoc_server_description_round_trip_time (
+   const mongoc_server_description_t *description)
 {
-   return description->round_trip_time;
+   return description->round_trip_time_msec;
 }
 
 /*
@@ -311,7 +328,7 @@ mongoc_server_description_round_trip_time (mongoc_server_description_t *descript
  */
 
 const char *
-mongoc_server_description_type (mongoc_server_description_t *description)
+mongoc_server_description_type (const mongoc_server_description_t *description)
 {
    switch (description->type) {
    case MONGOC_SERVER_UNKNOWN:
@@ -353,7 +370,8 @@ mongoc_server_description_type (mongoc_server_description_t *description)
  */
 
 const bson_t *
-mongoc_server_description_ismaster (mongoc_server_description_t *description)
+mongoc_server_description_ismaster (
+   const mongoc_server_description_t *description)
 {
    return &description->last_is_master;
 }
@@ -387,8 +405,8 @@ mongoc_server_description_set_state (mongoc_server_description_t *description,
  *--------------------------------------------------------------------------
  */
 void
-mongoc_server_description_set_set_version (mongoc_server_description_t *description,
-                                           int64_t set_version)
+mongoc_server_description_set_set_version (
+   mongoc_server_description_t *description, int64_t set_version)
 {
    description->set_version = set_version;
 }
@@ -407,8 +425,8 @@ mongoc_server_description_set_set_version (mongoc_server_description_t *descript
  *--------------------------------------------------------------------------
  */
 void
-mongoc_server_description_set_election_id (mongoc_server_description_t *description,
-                                           const bson_oid_t *election_id)
+mongoc_server_description_set_election_id (
+   mongoc_server_description_t *description, const bson_oid_t *election_id)
 {
    if (election_id) {
       bson_oid_copy_unsafe (election_id, &description->election_id);
@@ -432,34 +450,55 @@ mongoc_server_description_set_election_id (mongoc_server_description_t *descript
  */
 void
 mongoc_server_description_update_rtt (mongoc_server_description_t *server,
-                                      int64_t                      new_time)
+                                      int64_t rtt_msec)
 {
-   if (server->round_trip_time == -1) {
-      server->round_trip_time = new_time;
+   if (server->round_trip_time_msec == -1) {
+      server->round_trip_time_msec = rtt_msec;
    } else {
-      server->round_trip_time = ALPHA * new_time + (1 - ALPHA) * server->round_trip_time;
+      server->round_trip_time_msec = (int64_t) (
+         ALPHA * rtt_msec + (1 - ALPHA) * server->round_trip_time_msec);
    }
 }
 
+
+static void
+_mongoc_server_description_set_error (mongoc_server_description_t *sd,
+                                      const bson_error_t *error)
+{
+   if (error && error->code) {
+      memcpy (&sd->error, error, sizeof (bson_error_t));
+   } else {
+      bson_set_error (&sd->error,
+                      MONGOC_ERROR_STREAM,
+                      MONGOC_ERROR_STREAM_CONNECT,
+                      "unknown error calling ismaster");
+   }
+
+   /* Server Discovery and Monitoring Spec: if the server type changes from a
+    * known type to Unknown its RTT is set to null. */
+   sd->round_trip_time_msec = -1;
+}
+
+
 /*
  *-------------------------------------------------------------------------
  *
- * Called during SDAM, from topology description's ismaster handler.
+ * Called during SDAM, from topology description's ismaster handler, or
+ * when handshaking a connection in _mongoc_cluster_stream_for_server.
+ *
+ * If @ismaster_response is empty, @error must say why ismaster failed.
  *
  *-------------------------------------------------------------------------
  */
 
 void
-mongoc_server_description_handle_ismaster (
-   mongoc_server_description_t   *sd,
-   const bson_t                  *ismaster_response,
-   int64_t                        rtt_msec,
-   bson_error_t                  *error)
+mongoc_server_description_handle_ismaster (mongoc_server_description_t *sd,
+                                           const bson_t *ismaster_response,
+                                           int64_t rtt_msec,
+                                           const bson_error_t *error /* IN */)
 {
    bson_iter_t iter;
-#ifdef MONGOC_EXPERIMENTAL_FEATURES
    bson_iter_t child;
-#endif
    bool is_master = false;
    bool is_shard = false;
    bool is_secondary = false;
@@ -475,6 +514,7 @@ mongoc_server_description_handle_ismaster (
 
    mongoc_server_description_reset (sd);
    if (!ismaster_response) {
+      _mongoc_server_description_set_error (sd, error);
       EXIT;
    }
 
@@ -488,71 +528,89 @@ mongoc_server_description_handle_ismaster (
       num_keys++;
       if (strcmp ("ok", bson_iter_key (&iter)) == 0) {
          /* ismaster responses never have ok: 0, but spec requires we check */
-         if (! bson_iter_as_bool (&iter)) goto failure;
+         if (!bson_iter_as_bool (&iter))
+            goto failure;
       } else if (strcmp ("ismaster", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_BOOL (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_BOOL (&iter))
+            goto failure;
          is_master = bson_iter_bool (&iter);
       } else if (strcmp ("me", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_UTF8 (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_UTF8 (&iter))
+            goto failure;
          sd->me = bson_iter_utf8 (&iter, NULL);
       } else if (strcmp ("maxMessageSizeBytes", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_INT32 (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_INT32 (&iter))
+            goto failure;
          sd->max_msg_size = bson_iter_int32 (&iter);
       } else if (strcmp ("maxBsonObjectSize", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_INT32 (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_INT32 (&iter))
+            goto failure;
          sd->max_bson_obj_size = bson_iter_int32 (&iter);
       } else if (strcmp ("maxWriteBatchSize", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_INT32 (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_INT32 (&iter))
+            goto failure;
          sd->max_write_batch_size = bson_iter_int32 (&iter);
       } else if (strcmp ("minWireVersion", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_INT32 (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_INT32 (&iter))
+            goto failure;
          sd->min_wire_version = bson_iter_int32 (&iter);
       } else if (strcmp ("maxWireVersion", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_INT32 (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_INT32 (&iter))
+            goto failure;
          sd->max_wire_version = bson_iter_int32 (&iter);
       } else if (strcmp ("msg", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_UTF8 (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_UTF8 (&iter))
+            goto failure;
          is_shard = !!bson_iter_utf8 (&iter, NULL);
       } else if (strcmp ("setName", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_UTF8 (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_UTF8 (&iter))
+            goto failure;
          sd->set_name = bson_iter_utf8 (&iter, NULL);
       } else if (strcmp ("setVersion", bson_iter_key (&iter)) == 0) {
          mongoc_server_description_set_set_version (sd,
                                                     bson_iter_as_int64 (&iter));
       } else if (strcmp ("electionId", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_OID (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_OID (&iter))
+            goto failure;
          mongoc_server_description_set_election_id (sd, bson_iter_oid (&iter));
       } else if (strcmp ("secondary", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_BOOL (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_BOOL (&iter))
+            goto failure;
          is_secondary = bson_iter_bool (&iter);
       } else if (strcmp ("hosts", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_ARRAY (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_ARRAY (&iter))
+            goto failure;
          bson_iter_array (&iter, &len, &bytes);
          bson_init_static (&sd->hosts, bytes, len);
       } else if (strcmp ("passives", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_ARRAY (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_ARRAY (&iter))
+            goto failure;
          bson_iter_array (&iter, &len, &bytes);
          bson_init_static (&sd->passives, bytes, len);
       } else if (strcmp ("arbiters", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_ARRAY (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_ARRAY (&iter))
+            goto failure;
          bson_iter_array (&iter, &len, &bytes);
          bson_init_static (&sd->arbiters, bytes, len);
       } else if (strcmp ("primary", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_UTF8 (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_UTF8 (&iter))
+            goto failure;
          sd->current_primary = bson_iter_utf8 (&iter, NULL);
       } else if (strcmp ("arbiterOnly", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_BOOL (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_BOOL (&iter))
+            goto failure;
          is_arbiter = bson_iter_bool (&iter);
       } else if (strcmp ("isreplicaset", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_BOOL (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_BOOL (&iter))
+            goto failure;
          is_replicaset = bson_iter_bool (&iter);
       } else if (strcmp ("tags", bson_iter_key (&iter)) == 0) {
-         if (! BSON_ITER_HOLDS_DOCUMENT (&iter)) goto failure;
+         if (!BSON_ITER_HOLDS_DOCUMENT (&iter))
+            goto failure;
          bson_iter_document (&iter, &len, &bytes);
          bson_init_static (&sd->tags, bytes, len);
       } else if (strcmp ("hidden", bson_iter_key (&iter)) == 0) {
          is_hidden = bson_iter_bool (&iter);
-#ifdef MONGOC_EXPERIMENTAL_FEATURES
       } else if (strcmp ("lastWrite", bson_iter_key (&iter)) == 0) {
          if (!BSON_ITER_HOLDS_DOCUMENT (&iter) ||
              !bson_iter_recurse (&iter, &child) ||
@@ -562,6 +620,14 @@ mongoc_server_description_handle_ismaster (
          }
 
          sd->last_write_date_ms = bson_iter_date_time (&child);
+      } else if (strcmp ("idleWritePeriodMillis", bson_iter_key (&iter)) == 0) {
+         sd->last_write_date_ms = bson_iter_as_int64 (&iter);
+#ifdef MONGOC_ENABLE_COMPRESSION
+      } else if (strcmp ("compression", bson_iter_key (&iter)) == 0) {
+         if (!BSON_ITER_HOLDS_ARRAY (&iter))
+            goto failure;
+         bson_iter_array (&iter, &len, &bytes);
+         bson_init_static (&sd->compressors, bytes, len);
 #endif
       }
    }
@@ -588,13 +654,18 @@ mongoc_server_description_handle_ismaster (
       sd->type = MONGOC_SERVER_UNKNOWN;
    }
 
-   mongoc_server_description_update_rtt(sd, rtt_msec);
+   if (!num_keys) {
+      /* empty reply means ismaster failed */
+      _mongoc_server_description_set_error (sd, error);
+   }
+
+   mongoc_server_description_update_rtt (sd, rtt_msec);
 
    EXIT;
 
 failure:
    sd->type = MONGOC_SERVER_UNKNOWN;
-   sd->round_trip_time = -1;
+   sd->round_trip_time_msec = -1;
 
    EXIT;
 }
@@ -609,7 +680,8 @@ failure:
  *-------------------------------------------------------------------------
  */
 mongoc_server_description_t *
-mongoc_server_description_new_copy (const mongoc_server_description_t *description)
+mongoc_server_description_new_copy (
+   const mongoc_server_description_t *description)
 {
    mongoc_server_description_t *copy;
 
@@ -617,11 +689,12 @@ mongoc_server_description_new_copy (const mongoc_server_description_t *descripti
       return NULL;
    }
 
-   copy = (mongoc_server_description_t *)bson_malloc0(sizeof (*copy));
+   copy = (mongoc_server_description_t *) bson_malloc0 (sizeof (*copy));
 
    copy->id = description->id;
+   copy->opened = description->opened;
    memcpy (&copy->host, &description->host, sizeof (copy->host));
-   copy->round_trip_time = -1;
+   copy->round_trip_time_msec = -1;
 
    copy->connection_address = copy->host.host_and_port;
 
@@ -629,16 +702,26 @@ mongoc_server_description_new_copy (const mongoc_server_description_t *descripti
    copy->has_is_master = false;
    copy->set_version = MONGOC_NO_SET_VERSION;
    bson_init_static (&copy->hosts, kMongocEmptyBson, sizeof (kMongocEmptyBson));
-   bson_init_static (&copy->passives, kMongocEmptyBson, sizeof (kMongocEmptyBson));
-   bson_init_static (&copy->arbiters, kMongocEmptyBson, sizeof (kMongocEmptyBson));
+   bson_init_static (
+      &copy->passives, kMongocEmptyBson, sizeof (kMongocEmptyBson));
+   bson_init_static (
+      &copy->arbiters, kMongocEmptyBson, sizeof (kMongocEmptyBson));
    bson_init_static (&copy->tags, kMongocEmptyBson, sizeof (kMongocEmptyBson));
+#ifdef MONGOC_ENABLE_COMPRESSION
+   bson_init_static (
+      &copy->compressors, kMongocEmptyBson, sizeof (kMongocEmptyBson));
+#endif
 
    bson_init (&copy->last_is_master);
 
    if (description->has_is_master) {
-      mongoc_server_description_handle_ismaster (copy, &description->last_is_master,
-                                                 description->round_trip_time, NULL);
+      mongoc_server_description_handle_ismaster (
+         copy,
+         &description->last_is_master,
+         description->round_trip_time_msec,
+         &description->error);
    }
+
    /* Preserve the error */
    memcpy (&copy->error, &description->error, sizeof copy->error);
    return copy;
@@ -659,32 +742,36 @@ mongoc_server_description_new_copy (const mongoc_server_description_t *descripti
 
 void
 mongoc_server_description_filter_stale (mongoc_server_description_t **sds,
-                                        size_t                        sds_len,
-                                        mongoc_server_description_t  *primary,
-                                        int64_t                       heartbeat_frequency_ms,
-                                        const mongoc_read_prefs_t    *read_prefs)
+                                        size_t sds_len,
+                                        mongoc_server_description_t *primary,
+                                        int64_t heartbeat_frequency_ms,
+                                        const mongoc_read_prefs_t *read_prefs)
 {
-#ifdef MONGOC_EXPERIMENTAL_FEATURES
-   int64_t max_staleness_ms;
-   int64_t max_last_write_date_ms;
+   int64_t max_staleness_seconds;
    size_t i;
 
+   int64_t heartbeat_frequency_usec;
+   int64_t max_last_write_date_usec;
+   int64_t staleness_usec;
+   int64_t max_staleness_usec;
+
    if (!read_prefs) {
-      /* NULL read_prefs is PRIMARY, no maxStalenessMS to filter by */
+      /* NULL read_prefs is PRIMARY, no maxStalenessSeconds to filter by */
       return;
    }
 
-   max_staleness_ms = mongoc_read_prefs_get_max_staleness_ms (read_prefs);
-   BSON_ASSERT (max_staleness_ms >= 0);
+   max_staleness_seconds =
+      mongoc_read_prefs_get_max_staleness_seconds (read_prefs);
 
-   if (max_staleness_ms == 0) {
-      /* 0 means "no max staleness" */
+   if (max_staleness_seconds == MONGOC_NO_MAX_STALENESS) {
       return;
    }
 
+   BSON_ASSERT (max_staleness_seconds > 0);
+   max_staleness_usec = max_staleness_seconds * 1000 * 1000;
+   heartbeat_frequency_usec = heartbeat_frequency_ms * 1000;
+
    if (primary) {
-      int64_t staleness_usec;
-
       for (i = 0; i < sds_len; i++) {
          if (!sds[i] || sds[i]->type != MONGOC_SERVER_RS_SECONDARY) {
             continue;
@@ -694,22 +781,21 @@ mongoc_server_description_filter_stale (mongoc_server_description_t **sds,
          staleness_usec =
             primary->last_write_date_ms * 1000 +
             (sds[i]->last_update_time_usec - primary->last_update_time_usec) -
-            sds[i]->last_write_date_ms * 1000 +
-            heartbeat_frequency_ms * 1000;
+            sds[i]->last_write_date_ms * 1000 + heartbeat_frequency_usec;
 
-         if (staleness_usec > max_staleness_ms * 1000) {
+         if (staleness_usec > max_staleness_usec) {
+            TRACE ("Rejected stale RSSecondary [%s]",
+                   sds[i]->host.host_and_port);
             sds[i] = NULL;
          }
       }
    } else {
-      int64_t staleness_ms;
-
       /* find max last_write_date */
-      max_last_write_date_ms = 0;
+      max_last_write_date_usec = 0;
       for (i = 0; i < sds_len; i++) {
-         if (sds[i] && sds[i]->type == MONGOC_SERVER_RS_SECONDARY &&
-             sds[i]->last_write_date_ms > max_last_write_date_ms) {
-            max_last_write_date_ms = sds[i]->last_write_date_ms;
+         if (sds[i] && sds[i]->type == MONGOC_SERVER_RS_SECONDARY) {
+            max_last_write_date_usec = BSON_MAX (
+               max_last_write_date_usec, sds[i]->last_write_date_ms * 1000);
          }
       }
 
@@ -719,16 +805,17 @@ mongoc_server_description_filter_stale (mongoc_server_description_t **sds,
             continue;
          }
 
-         staleness_ms = max_last_write_date_ms -
-                        sds[i]->last_write_date_ms +
-                        heartbeat_frequency_ms;
+         staleness_usec = max_last_write_date_usec -
+                          sds[i]->last_write_date_ms * 1000 +
+                          heartbeat_frequency_usec;
 
-         if (staleness_ms > max_staleness_ms) {
+         if (staleness_usec > max_staleness_usec) {
+            TRACE ("Rejected stale RSSecondary [%s]",
+                   sds[i]->host.host_and_port);
             sds[i] = NULL;
          }
       }
    }
-#endif
 }
 
 
@@ -746,9 +833,10 @@ mongoc_server_description_filter_stale (mongoc_server_description_t **sds,
  */
 
 void
-mongoc_server_description_filter_tags (mongoc_server_description_t **descriptions,
-                                       size_t                        description_len,
-                                       const mongoc_read_prefs_t    *read_prefs)
+mongoc_server_description_filter_tags (
+   mongoc_server_description_t **descriptions,
+   size_t description_len,
+   const mongoc_read_prefs_t *read_prefs)
 {
    const bson_t *rp_tags;
    bson_iter_t rp_tagset_iter;
@@ -769,7 +857,7 @@ mongoc_server_description_filter_tags (mongoc_server_description_t **description
       return;
    }
 
-   sd_matched = (bool *) bson_malloc0 (sizeof(bool) * description_len);
+   sd_matched = (bool *) bson_malloc0 (sizeof (bool) * description_len);
 
    bson_iter_init (&rp_tagset_iter, rp_tags);
 
@@ -792,7 +880,10 @@ mongoc_server_description_filter_tags (mongoc_server_description_t **description
 
       if (found) {
          for (i = 0; i < description_len; i++) {
-            if (! sd_matched[i]) {
+            if (!sd_matched[i] && descriptions[i]) {
+               TRACE ("Rejected [%s] [%s], doesn't match tags",
+                      mongoc_server_description_type (descriptions[i]),
+                      descriptions[i]->host.host_and_port);
                descriptions[i] = NULL;
             }
          }
@@ -803,7 +894,11 @@ mongoc_server_description_filter_tags (mongoc_server_description_t **description
 
    /* tried each */
    for (i = 0; i < description_len; i++) {
-      if (! sd_matched[i]) {
+      if (!sd_matched[i]) {
+         TRACE ("Rejected [%s] [%s], reached end of tags array without match",
+                mongoc_server_description_type (descriptions[i]),
+                descriptions[i]->host.host_and_port);
+
          descriptions[i] = NULL;
       }
    }
@@ -823,8 +918,9 @@ CLEANUP:
  *
  *-------------------------------------------------------------------------
  */
-static bool _match_tag_set (const mongoc_server_description_t *sd,
-                            bson_iter_t                       *tag_set_iter)
+static bool
+_match_tag_set (const mongoc_server_description_t *sd,
+                bson_iter_t *tag_set_iter)
 {
    bson_iter_t sd_iter;
    uint32_t read_pref_tag_len;
@@ -842,7 +938,7 @@ static bool _match_tag_set (const mongoc_server_description_t *sd,
          /* The server has this tag - does it have the right value? */
          server_val = bson_iter_utf8 (&sd_iter, &sd_len);
          if (sd_len != read_pref_tag_len ||
-             memcmp(read_pref_val, server_val, read_pref_tag_len)) {
+             memcmp (read_pref_val, server_val, read_pref_tag_len)) {
             /* If the values don't match, no match */
             return false;
          }
@@ -854,3 +950,36 @@ static bool _match_tag_set (const mongoc_server_description_t *sd,
 
    return true;
 }
+
+#ifdef MONGOC_ENABLE_COMPRESSION
+/*
+ *--------------------------------------------------------------------------
+ *
+ * mongoc_server_description_id --
+ *
+ *      Get the compressor id if compression was negotiated.
+ *
+ * Returns:
+ *      The compressor ID, or 0 if none was negotiated.
+ *
+ *--------------------------------------------------------------------------
+ */
+
+int32_t
+mongoc_server_description_compressor_id (
+   const mongoc_server_description_t *description)
+{
+   int id;
+   bson_iter_t iter;
+   bson_iter_init (&iter, &description->compressors);
+
+   while (bson_iter_next (&iter)) {
+      id = mongoc_compressor_name_to_id (bson_iter_utf8 (&iter, NULL));
+      if (id != -1) {
+         return id;
+      }
+   }
+
+   return 0;
+}
+#endif
