@@ -18,20 +18,18 @@
 #ifndef MONGOC_TESTS_H
 #define MONGOC_TESTS_H
 
-#include <assert.h>
 #include <bson.h>
 #include <stdio.h>
 #include <time.h>
 #ifdef _WIN32
-# include <process.h>
+#include <process.h>
 #endif
 
 
 BSON_BEGIN_DECLS
 
 void
-run_test (const char *name,
-          void (*func) (void));
+run_test (const char *name, void (*func) (void));
 
 BSON_END_DECLS
 
