@@ -16,7 +16,8 @@
 #define MONGOC_LOG_DOMAIN "cluster-test"
 
 
-static uint32_t server_id_for_reads (mongoc_cluster_t *cluster)
+static uint32_t
+server_id_for_reads (mongoc_cluster_t *cluster)
 {
    bson_error_t error;
    mongoc_server_stream_t *server_stream;
@@ -44,12 +45,14 @@ test_get_max_bson_obj_size (void)
 
    /* single-threaded */
    client = test_framework_client_new ();
-   assert (client);
+   BSON_ASSERT (client);
 
    id = server_id_for_reads (&client->cluster);
-   sd = (mongoc_server_description_t *)mongoc_set_get (client->topology->description.servers, id);
+   sd = (mongoc_server_description_t *) mongoc_set_get (
+      client->topology->description.servers, id);
    sd->max_bson_obj_size = max_bson_obj_size;
-   assert (max_bson_obj_size == mongoc_cluster_get_max_bson_obj_size (&client->cluster));
+   BSON_ASSERT (max_bson_obj_size ==
+                mongoc_cluster_get_max_bson_obj_size (&client->cluster));
 
    mongoc_client_destroy (client);
 
@@ -58,9 +61,10 @@ test_get_max_bson_obj_size (void)
    client = mongoc_client_pool_pop (pool);
 
    id = server_id_for_reads (&client->cluster);
-   node = (mongoc_cluster_node_t *)mongoc_set_get (client->cluster.nodes, id);
+   node = (mongoc_cluster_node_t *) mongoc_set_get (client->cluster.nodes, id);
    node->max_bson_obj_size = max_bson_obj_size;
-   assert (max_bson_obj_size == mongoc_cluster_get_max_bson_obj_size (&client->cluster));
+   BSON_ASSERT (max_bson_obj_size ==
+                mongoc_cluster_get_max_bson_obj_size (&client->cluster));
 
    mongoc_client_pool_push (pool, client);
    mongoc_client_pool_destroy (pool);
@@ -80,9 +84,11 @@ test_get_max_msg_size (void)
    client = test_framework_client_new ();
    id = server_id_for_reads (&client->cluster);
 
-   sd = (mongoc_server_description_t *)mongoc_set_get (client->topology->description.servers, id);
+   sd = (mongoc_server_description_t *) mongoc_set_get (
+      client->topology->description.servers, id);
    sd->max_msg_size = max_msg_size;
-   assert (max_msg_size == mongoc_cluster_get_max_msg_size (&client->cluster));
+   BSON_ASSERT (max_msg_size ==
+                mongoc_cluster_get_max_msg_size (&client->cluster));
 
    mongoc_client_destroy (client);
 
@@ -91,39 +97,43 @@ test_get_max_msg_size (void)
    client = mongoc_client_pool_pop (pool);
 
    id = server_id_for_reads (&client->cluster);
-   node = (mongoc_cluster_node_t *)mongoc_set_get (client->cluster.nodes, id);
+   node = (mongoc_cluster_node_t *) mongoc_set_get (client->cluster.nodes, id);
    node->max_msg_size = max_msg_size;
-   assert (max_msg_size == mongoc_cluster_get_max_msg_size (&client->cluster));
+   BSON_ASSERT (max_msg_size ==
+                mongoc_cluster_get_max_msg_size (&client->cluster));
 
    mongoc_client_pool_push (pool, client);
    mongoc_client_pool_destroy (pool);
 }
 
 
-#define ASSERT_CURSOR_ERR() do { \
-      assert (!future_get_bool (future)); \
-      assert (mongoc_cursor_error (cursor, &error)); \
-      ASSERT_ERROR_CONTAINS(error, \
-                            MONGOC_ERROR_STREAM, \
-                            MONGOC_ERROR_STREAM_SOCKET, \
-                            "Failed to read 4 bytes: socket error or timeout");\
+#define ASSERT_CURSOR_ERR()                                  \
+   do {                                                      \
+      BSON_ASSERT (!future_get_bool (future));               \
+      BSON_ASSERT (mongoc_cursor_error (cursor, &error));    \
+      ASSERT_ERROR_CONTAINS (                                \
+         error,                                              \
+         MONGOC_ERROR_STREAM,                                \
+         MONGOC_ERROR_STREAM_SOCKET,                         \
+         "Failed to read 4 bytes: socket error or timeout"); \
    } while (0)
 
 
-#define START_QUERY(client_port_variable) do { \
-      cursor = mongoc_collection_find_with_opts (collection, tmp_bson ("{}"), \
-                                                 NULL, NULL); \
-      future = future_cursor_next (cursor, &doc); \
-      request = mock_server_receives_query (server, "test.test", \
-                                            MONGOC_QUERY_SLAVE_OK, 0, 0, \
-                                            "{}", NULL); \
-      client_port_variable = request_get_client_port (request); \
+#define START_QUERY(client_port_variable)                               \
+   do {                                                                 \
+      cursor = mongoc_collection_find_with_opts (                       \
+         collection, tmp_bson ("{}"), NULL, NULL);                      \
+      future = future_cursor_next (cursor, &doc);                       \
+      request = mock_server_receives_query (                            \
+         server, "test.test", MONGOC_QUERY_SLAVE_OK, 0, 0, "{}", NULL); \
+      client_port_variable = request_get_client_port (request);         \
    } while (0)
 
 
-#define CLEANUP_QUERY() do { \
-      request_destroy (request); \
-      future_destroy (future); \
+#define CLEANUP_QUERY()               \
+   do {                               \
+      request_destroy (request);      \
+      future_destroy (future);        \
       mongoc_cursor_destroy (cursor); \
    } while (0)
 
@@ -145,6 +155,10 @@ _test_cluster_node_disconnect (bool pooled)
    uint16_t client_port_0, client_port_1;
    bson_error_t error;
 
+   if (!TestSuite_CheckMockServerAllowed ()) {
+      return;
+   }
+
    capture_logs (true);
 
    server = mock_server_with_autoismaster (0);
@@ -234,26 +248,28 @@ _test_cluster_command_timeout (bool pooled)
    }
 
    /* server doesn't respond in time */
-   future = future_client_command_simple (client, "db", tmp_bson ("{'foo': 1}"),
-                                          NULL, NULL, &error);
-   request = mock_server_receives_command (server, "db", MONGOC_QUERY_SLAVE_OK,
-                                           NULL);
+   future = future_client_command_simple (
+      client, "db", tmp_bson ("{'foo': 1}"), NULL, NULL, &error);
+   request =
+      mock_server_receives_command (server, "db", MONGOC_QUERY_SLAVE_OK, NULL);
    client_port = request_get_client_port (request);
 
    ASSERT (!future_get_bool (future));
-   ASSERT_ERROR_CONTAINS (error,
-                          MONGOC_ERROR_STREAM, MONGOC_ERROR_STREAM_SOCKET,
-                          "Failed to send \"foo\" command with database \"db\"");
+   ASSERT_ERROR_CONTAINS (
+      error,
+      MONGOC_ERROR_STREAM,
+      MONGOC_ERROR_STREAM_SOCKET,
+      "Failed to send \"foo\" command with database \"db\"");
 
    /* late response */
    mock_server_replies_simple (request, "{'ok': 1, 'bar': 1}");
    request_destroy (request);
    future_destroy (future);
 
-   future = future_client_command_simple (client, "db", tmp_bson ("{'baz': 1}"),
-                                          NULL, &reply, &error);
-   request = mock_server_receives_command (server, "db", MONGOC_QUERY_SLAVE_OK,
-                                           "{'baz': 1}");
+   future = future_client_command_simple (
+      client, "db", tmp_bson ("{'baz': 1}"), NULL, &reply, &error);
+   request = mock_server_receives_command (
+      server, "db", MONGOC_QUERY_SLAVE_OK, "{'baz': 1}");
    ASSERT (request);
    /* new socket */
    ASSERT_CMPUINT16 (client_port, !=, request_get_client_port (request));
@@ -304,6 +320,10 @@ _test_write_disconnect (bool legacy)
    request_t *request;
    mongoc_topology_scanner_node_t *scanner_node;
 
+   if (!TestSuite_CheckMockServerAllowed ()) {
+      return;
+   }
+
    server = mock_server_new ();
    mock_server_run (server);
    client = mongoc_client_new_from_uri (mock_server_get_uri (server));
@@ -311,8 +331,8 @@ _test_write_disconnect (bool legacy)
    /*
     * establish connection with an "ismaster" and "ping"
     */
-   future = future_client_command_simple (client, "db", tmp_bson ("{'ping': 1}"),
-                                          NULL, NULL, &error);
+   future = future_client_command_simple (
+      client, "db", tmp_bson ("{'ping': 1}"), NULL, NULL, &error);
    request = mock_server_receives_ismaster (server);
    ismaster_response = bson_strdup_printf ("{'ok': 1.0,"
                                            " 'ismaster': true,"
@@ -323,16 +343,11 @@ _test_write_disconnect (bool legacy)
    mock_server_replies_simple (request, ismaster_response);
    request_destroy (request);
 
-   request = mock_server_receives_command (server, "db", MONGOC_QUERY_SLAVE_OK,
-                                           "{'ping': 1}");
+   request = mock_server_receives_command (
+      server, "db", MONGOC_QUERY_SLAVE_OK, "{'ping': 1}");
    mock_server_replies_simple (request, "{'ok': 1}");
    ASSERT_OR_PRINT (future_get_bool (future), error);
 
-   /*
-    * wait for CHECK_CLOSED_DURATION_MSEC to elapse
-    */
-   _mongoc_usleep (1100 * 1000);
-
    /*
     * close the socket
     */
@@ -343,12 +358,12 @@ _test_write_disconnect (bool legacy)
     */
    collection = mongoc_client_get_collection (client, "db", "collection");
    future_destroy (future);
-   future = future_collection_insert (collection, MONGOC_INSERT_NONE,
-                                      tmp_bson ("{'_id': 1}"), NULL, &error);
+   future = future_collection_insert (
+      collection, MONGOC_INSERT_NONE, tmp_bson ("{'_id': 1}"), NULL, &error);
 
    ASSERT (!future_get_bool (future));
    ASSERT_CMPINT (error.domain, ==, MONGOC_ERROR_STREAM);
-   ASSERT_CMPINT (error.code, == , MONGOC_ERROR_STREAM_SOCKET);
+   ASSERT_CMPINT (error.code, ==, MONGOC_ERROR_STREAM_SOCKET);
 
    scanner_node = mongoc_topology_scanner_get_node (client->topology->scanner,
                                                     1 /* server_id */);
@@ -377,106 +392,41 @@ test_legacy_write_disconnect (void *ctx)
 }
 
 
-static void
-_test_socket_check (bool legacy)
-{
-   mock_server_t *server;
-   mongoc_uri_t *uri;
-   char *ismaster_response;
-   mongoc_client_t *client;
-   mongoc_collection_t *collection;
-   bson_error_t error;
-   future_t *future;
-   request_t *request;
-   mongoc_topology_scanner_node_t *scanner_node;
-
-   server = mock_server_new ();
-   mock_server_run (server);
-   uri = mongoc_uri_copy (mock_server_get_uri (server));
-   mongoc_uri_set_option_as_int32 (uri, "socketCheckIntervalMS", 1);
-   client = mongoc_client_new_from_uri (uri);
-
-   /*
-    * establish connection with an "ismaster" and "ping"
-    */
-   future = future_client_command_simple (client, "db", tmp_bson ("{'ping': 1}"),
-                                          NULL, NULL, &error);
-   request = mock_server_receives_ismaster (server);
-   ismaster_response = bson_strdup_printf ("{'ok': 1.0,"
-                                           " 'ismaster': true,"
-                                           " 'minWireVersion': 0,"
-                                           " 'maxWireVersion': %d}",
-                                           legacy ? 0 : 3);
-
-   mock_server_replies_simple (request, ismaster_response);
-   request_destroy (request);
-
-   request = mock_server_receives_command (server, "db", MONGOC_QUERY_SLAVE_OK,
-                                           "{'ping': 1}");
-   mock_server_replies_simple (request, "{'ok': 1}");
-   ASSERT_OR_PRINT (future_get_bool (future), error);
-
-   /*
-    * wait for socketCheckIntervalMS to elapse
-    */
-   _mongoc_usleep (2000);
-
-   /*
-    * close the socket
-    */
-   mock_server_hangs_up (request);
-
-   /*
-    * next operation detects the hangup
-    */
-   collection = mongoc_client_get_collection (client, "db", "collection");
-   future_destroy (future);
-   future = future_collection_insert (collection, MONGOC_INSERT_NONE,
-                                      tmp_bson ("{'_id': 1}"), NULL, &error);
-
-   ASSERT (!future_get_bool (future));
-   ASSERT_CMPINT (error.domain, ==, MONGOC_ERROR_STREAM);
-   ASSERT_CMPINT (error.code, == , MONGOC_ERROR_STREAM_SOCKET);
-
-   scanner_node = mongoc_topology_scanner_get_node (client->topology->scanner,
-                                                    1 /* server_id */);
-   ASSERT (scanner_node && !scanner_node->stream);
-
-   mongoc_collection_destroy (collection);
-   request_destroy (request);
-   future_destroy (future);
-   bson_free (ismaster_response);
-   mongoc_client_destroy (client);
-   mongoc_uri_destroy (uri);
-   mock_server_destroy (server);
-}
-
-
-static void
-test_write_command_socket_check (void)
-{
-   _test_socket_check (false);
-}
-
-
-static void
-test_legacy_write_socket_check (void)
-{
-   _test_socket_check (true);
-}
-
-
 void
 test_cluster_install (TestSuite *suite)
 {
-   TestSuite_AddLive (suite, "/Cluster/test_get_max_bson_obj_size", test_get_max_bson_obj_size);
-   TestSuite_AddLive (suite, "/Cluster/test_get_max_msg_size", test_get_max_msg_size);
-   TestSuite_AddFull  (suite, "/Cluster/disconnect/single", test_cluster_node_disconnect_single, NULL, NULL, test_framework_skip_if_slow);
-   TestSuite_AddFull  (suite, "/Cluster/disconnect/pooled", test_cluster_node_disconnect_pooled, NULL, NULL, test_framework_skip_if_slow);
-   TestSuite_Add (suite, "/Cluster/command/timeout/single", test_cluster_command_timeout_single);
-   TestSuite_Add (suite, "/Cluster/command/timeout/pooled", test_cluster_command_timeout_pooled);
-   TestSuite_AddFull (suite, "/Cluster/write_command/disconnect", test_write_command_disconnect, NULL, NULL, test_framework_skip_if_slow);
-   TestSuite_AddFull  (suite, "/Cluster/legacy_write/disconnect", test_legacy_write_disconnect, NULL, NULL, test_framework_skip_if_slow);
-   TestSuite_Add (suite, "/Cluster/write_command/socket_check", test_write_command_socket_check);
-   TestSuite_Add (suite, "/Cluster/legacy_write/socket_check", test_legacy_write_socket_check);
+   TestSuite_AddLive (
+      suite, "/Cluster/test_get_max_bson_obj_size", test_get_max_bson_obj_size);
+   TestSuite_AddLive (
+      suite, "/Cluster/test_get_max_msg_size", test_get_max_msg_size);
+   TestSuite_AddFull (suite,
+                      "/Cluster/disconnect/single",
+                      test_cluster_node_disconnect_single,
+                      NULL,
+                      NULL,
+                      test_framework_skip_if_slow);
+   TestSuite_AddFull (suite,
+                      "/Cluster/disconnect/pooled",
+                      test_cluster_node_disconnect_pooled,
+                      NULL,
+                      NULL,
+                      test_framework_skip_if_slow);
+   TestSuite_AddMockServerTest (suite,
+                                "/Cluster/command/timeout/single",
+                                test_cluster_command_timeout_single);
+   TestSuite_AddMockServerTest (suite,
+                                "/Cluster/command/timeout/pooled",
+                                test_cluster_command_timeout_pooled);
+   TestSuite_AddFull (suite,
+                      "/Cluster/write_command/disconnect",
+                      test_write_command_disconnect,
+                      NULL,
+                      NULL,
+                      test_framework_skip_if_slow);
+   TestSuite_AddFull (suite,
+                      "/Cluster/legacy_write/disconnect",
+                      test_legacy_write_disconnect,
+                      NULL,
+                      NULL,
+                      test_framework_skip_if_slow);
 }
