@@ -3,6 +3,8 @@
 #include <mongoc-apm-private.h>
 #include <mongoc-host-list-private.h>
 #include <mongoc-cursor-private.h>
+#include <mongoc-bulk-operation-private.h>
+#include <mongoc-client-private.h>
 
 #include "json-test.h"
 #include "test-libmongoc.h"
@@ -11,14 +13,13 @@
 #include "mock_server/future-functions.h"
 
 
-typedef struct
-{
-   uint32_t           n_events;
-   bson_t             events;
-   mongoc_uri_t      *test_framework_uri;
-   int64_t            cursor_id;
-   int64_t            operation_id;
-   bool               verbose;
+typedef struct {
+   uint32_t n_events;
+   bson_t events;
+   mongoc_uri_t *test_framework_uri;
+   int64_t cursor_id;
+   int64_t operation_id;
+   bool verbose;
 } context_t;
 
 
@@ -44,8 +45,7 @@ context_destroy (context_t *context)
 
 
 static int
-check_server_version (const bson_t *test,
-                      context_t *context)
+check_server_version (const bson_t *test, context_t *context)
 {
    const char *s;
    char *padded;
@@ -118,8 +118,7 @@ check_topology_type (const bson_t *test)
 
 
 static void
-insert_data (mongoc_collection_t *collection,
-             const bson_t        *test)
+insert_data (mongoc_collection_t *collection, const bson_t *test)
 {
    mongoc_bulk_operation_t *bulk;
    bson_iter_t iter;
@@ -156,8 +155,7 @@ insert_data (mongoc_collection_t *collection,
 
 
 static void
-assert_host_in_uri (const mongoc_host_list_t *host,
-                    const mongoc_uri_t       *uri)
+assert_host_in_uri (const mongoc_host_list_t *host, const mongoc_uri_t *uri)
 {
    const mongoc_host_list_t *hosts;
 
@@ -170,16 +168,17 @@ assert_host_in_uri (const mongoc_host_list_t *host,
       hosts = hosts->next;
    }
 
-   fprintf (stderr, "Host \"%s\" not in \"%s\"",
-            host->host_and_port, mongoc_uri_get_string (uri));
+   fprintf (stderr,
+            "Host \"%s\" not in \"%s\"",
+            host->host_and_port,
+            mongoc_uri_get_string (uri));
    fflush (stderr);
    abort ();
 }
 
 
 static bool
-ends_with (const char *s,
-           const char *suffix)
+ends_with (const char *s, const char *suffix)
 {
    size_t s_len;
    size_t suffix_len;
@@ -231,14 +230,15 @@ convert_command_for_test (context_t *context,
          BSON_APPEND_DOUBLE (dst, key, (double) bson_iter_as_int64 (&iter));
 
       } else if (!strcmp (key, "errmsg")) {
-         /* "errmsg values of "" MUST assert that the value is not empty" */
+         /* "errmsg values of "" MUST BSON_ASSERT that the value is not empty"
+          */
          errmsg = bson_iter_utf8 (&iter, NULL);
          ASSERT_CMPSIZE_T (strlen (errmsg), >, (size_t) 0);
          BSON_APPEND_UTF8 (dst, key, "");
 
       } else if (!strcmp (key, "id") && ends_with (path, "cursor")) {
          /* "When encountering a cursor or getMore value of "42" in a test, the
-          * driver MUST assert that the values are equal to each other and
+          * driver MUST BSON_ASSERT that the values are equal to each other and
           * greater than zero."
           */
          if (context->cursor_id == 0) {
@@ -248,7 +248,7 @@ convert_command_for_test (context_t *context,
          }
 
          /* replace the reply's cursor id with 42 or 0 - check_expectations()
-          * will assert it matches the value from the JSON test */
+          * will BSON_ASSERT it matches the value from the JSON test */
          BSON_APPEND_INT64 (dst, key, fake_cursor_id (&iter));
       } else if (ends_with (path, "cursors") ||
                  ends_with (path, "cursorsUnknown")) {
@@ -265,7 +265,8 @@ convert_command_for_test (context_t *context,
          BSON_APPEND_INT64 (dst, key, fake_cursor_id (&iter));
 
       } else if (!strcmp (key, "code")) {
-         /* "code values of 42 MUST assert that the value is present and greater
+         /* "code values of 42 MUST BSON_ASSERT that the value is present and
+          * greater
           * than zero" */
          ASSERT_CMPINT64 (bson_iter_as_int64 (&iter), >, (int64_t) 0);
          BSON_APPEND_INT32 (dst, key, 42);
@@ -279,7 +280,8 @@ convert_command_for_test (context_t *context,
 
          bson_iter_bson (&iter, &src_child);
          bson_append_document_begin (dst, key, -1, &dst_child);
-         convert_command_for_test (context, &src_child, &dst_child, child_path); /* recurse */
+         convert_command_for_test (
+            context, &src_child, &dst_child, child_path); /* recurse */
          bson_append_document_end (dst, &dst_child);
          bson_free (child_path);
       } else if (BSON_ITER_HOLDS_ARRAY (&iter)) {
@@ -291,7 +293,8 @@ convert_command_for_test (context_t *context,
 
          bson_iter_bson (&iter, &src_child);
          bson_append_array_begin (dst, key, -1, &dst_child);
-         convert_command_for_test (context, &src_child, &dst_child, child_path); /* recurse */
+         convert_command_for_test (
+            context, &src_child, &dst_child, child_path); /* recurse */
          bson_append_array_end (dst, &dst_child);
          bson_free (child_path);
       } else {
@@ -304,8 +307,8 @@ convert_command_for_test (context_t *context,
 static void
 started_cb (const mongoc_apm_command_started_t *event)
 {
-   context_t *context = (context_t *)
-      mongoc_apm_command_started_get_context (event);
+   context_t *context =
+      (context_t *) mongoc_apm_command_started_get_context (event);
    int64_t operation_id;
    char *cmd_json;
    bson_t *events = &context->events;
@@ -315,7 +318,7 @@ started_cb (const mongoc_apm_command_started_t *event)
    bson_t *new_event;
 
    if (context->verbose) {
-      cmd_json = bson_as_json (event->command, NULL);
+      cmd_json = bson_as_canonical_extended_json (event->command, NULL);
       printf ("%s\n", cmd_json);
       fflush (stdout);
       bson_free (cmd_json);
@@ -335,10 +338,14 @@ started_cb (const mongoc_apm_command_started_t *event)
    }
 
    convert_command_for_test (context, event->command, &cmd, NULL);
-   new_event = BCON_NEW ("command_started_event", "{",
-                         "command", BCON_DOCUMENT (&cmd),
-                         "command_name", BCON_UTF8 (event->command_name),
-                         "database_name", BCON_UTF8 (event->database_name),
+   new_event = BCON_NEW ("command_started_event",
+                         "{",
+                         "command",
+                         BCON_DOCUMENT (&cmd),
+                         "command_name",
+                         BCON_UTF8 (event->command_name),
+                         "database_name",
+                         BCON_UTF8 (event->database_name),
                          "}");
 
    bson_uint32_to_string (context->n_events, &key, str, sizeof str);
@@ -354,8 +361,8 @@ started_cb (const mongoc_apm_command_started_t *event)
 static void
 succeeded_cb (const mongoc_apm_command_succeeded_t *event)
 {
-   context_t *context = (context_t *)
-      mongoc_apm_command_succeeded_get_context (event);
+   context_t *context =
+      (context_t *) mongoc_apm_command_succeeded_get_context (event);
    int64_t operation_id;
    char *reply_json;
    bson_t reply = BSON_INITIALIZER;
@@ -364,7 +371,7 @@ succeeded_cb (const mongoc_apm_command_succeeded_t *event)
    bson_t *new_event;
 
    if (context->verbose) {
-      reply_json = bson_as_json (event->reply, NULL);
+      reply_json = bson_as_canonical_extended_json (event->reply, NULL);
       printf ("\t\t<-- %s\n", reply_json);
       fflush (stdout);
       bson_free (reply_json);
@@ -380,9 +387,12 @@ succeeded_cb (const mongoc_apm_command_succeeded_t *event)
    ASSERT_CMPINT64 (context->operation_id, ==, operation_id);
 
    convert_command_for_test (context, event->reply, &reply, NULL);
-   new_event = BCON_NEW ("command_succeeded_event", "{",
-                         "reply", BCON_DOCUMENT (&reply),
-                         "command_name", BCON_UTF8 (event->command_name),
+   new_event = BCON_NEW ("command_succeeded_event",
+                         "{",
+                         "reply",
+                         BCON_DOCUMENT (&reply),
+                         "command_name",
+                         BCON_UTF8 (event->command_name),
                          "}");
 
    bson_uint32_to_string (context->n_events, &key, str, sizeof str);
@@ -398,8 +408,8 @@ succeeded_cb (const mongoc_apm_command_succeeded_t *event)
 static void
 failed_cb (const mongoc_apm_command_failed_t *event)
 {
-   context_t *context = (context_t *)
-      mongoc_apm_command_failed_get_context (event);
+   context_t *context =
+      (context_t *) mongoc_apm_command_failed_get_context (event);
    int64_t operation_id;
    bson_t reply = BSON_INITIALIZER;
    char str[16];
@@ -407,8 +417,8 @@ failed_cb (const mongoc_apm_command_failed_t *event)
    bson_t *new_event;
 
    if (context->verbose) {
-      printf ("\t\t<-- %s FAILED: %s\n",
-              event->command_name, event->error->message);
+      printf (
+         "\t\t<-- %s FAILED: %s\n", event->command_name, event->error->message);
       fflush (stdout);
    }
 
@@ -421,8 +431,10 @@ failed_cb (const mongoc_apm_command_failed_t *event)
    ASSERT_CMPINT64 (operation_id, !=, (int64_t) 0);
    ASSERT_CMPINT64 (context->operation_id, ==, operation_id);
 
-   new_event = BCON_NEW ("command_failed_event", "{",
-                         "command_name", BCON_UTF8 (event->command_name),
+   new_event = BCON_NEW ("command_failed_event",
+                         "{",
+                         "command_name",
+                         BCON_UTF8 (event->command_name),
                          "}");
 
    bson_uint32_to_string (context->n_events, &key, str, sizeof str);
@@ -436,8 +448,7 @@ failed_cb (const mongoc_apm_command_failed_t *event)
 
 
 static void
-one_bulk_op (mongoc_bulk_operation_t *bulk,
-             const bson_t            *request)
+one_bulk_op (mongoc_bulk_operation_t *bulk, const bson_t *request)
 {
    bson_iter_t iter;
    const char *request_name;
@@ -454,8 +465,8 @@ one_bulk_op (mongoc_bulk_operation_t *bulk,
    } else if (!strcmp (request_name, "updateOne")) {
       bson_lookup_doc (&request_doc, "filter", &filter);
       bson_lookup_doc (&request_doc, "update", &update);
-      mongoc_bulk_operation_update_one (bulk, &filter, &update,
-                                        false /* upsert */);
+      mongoc_bulk_operation_update_one (
+         bulk, &filter, &update, false /* upsert */);
    } else {
       test_error ("unrecognized request name %s", request_name);
       abort ();
@@ -464,8 +475,7 @@ one_bulk_op (mongoc_bulk_operation_t *bulk,
 
 
 static void
-test_bulk_write (mongoc_collection_t *collection,
-                 const bson_t        *arguments)
+test_bulk_write (mongoc_collection_t *collection, const bson_t *arguments)
 {
    bool ordered;
    mongoc_write_concern_t *wc;
@@ -504,20 +514,19 @@ test_bulk_write (mongoc_collection_t *collection,
 
 
 static void
-test_count (mongoc_collection_t *collection,
-            const bson_t        *arguments)
+test_count (mongoc_collection_t *collection, const bson_t *arguments)
 {
    bson_t filter;
 
    bson_lookup_doc (arguments, "filter", &filter);
-   mongoc_collection_count (collection, MONGOC_QUERY_NONE, &filter,
-                            0, 0, NULL, NULL);
+   mongoc_collection_count (
+      collection, MONGOC_QUERY_NONE, &filter, 0, 0, NULL, NULL);
 }
 
 
 static void
 test_find (mongoc_collection_t *collection,
-           const bson_t        *arguments,
+           const bson_t *arguments,
            mongoc_read_prefs_t *read_prefs)
 {
    bson_t query;
@@ -532,8 +541,7 @@ test_find (mongoc_collection_t *collection,
 
    bson_lookup_doc (arguments, "filter", &filter);
 
-   if (read_prefs ||
-       bson_has_field (arguments, "sort") ||
+   if (read_prefs || bson_has_field (arguments, "sort") ||
        bson_has_field (arguments, "modifiers")) {
       bson_init (&query);
       BSON_APPEND_DOCUMENT (&query, "$query", &filter);
@@ -563,9 +571,14 @@ test_find (mongoc_collection_t *collection,
       batch_size = (uint32_t) bson_lookup_int64 (arguments, "batchSize");
    }
 
-   cursor = mongoc_collection_find (collection, MONGOC_QUERY_NONE,
-                                    skip, limit, batch_size, &query,
-                                    NULL, read_prefs);
+   cursor = mongoc_collection_find (collection,
+                                    MONGOC_QUERY_NONE,
+                                    skip,
+                                    limit,
+                                    batch_size,
+                                    &query,
+                                    NULL,
+                                    read_prefs);
 
    BSON_ASSERT (cursor);
    while (mongoc_cursor_next (cursor, &doc)) {
@@ -578,32 +591,29 @@ test_find (mongoc_collection_t *collection,
 
 
 static void
-test_delete_many (mongoc_collection_t *collection,
-                  const bson_t        *arguments)
+test_delete_many (mongoc_collection_t *collection, const bson_t *arguments)
 {
    bson_t filter;
 
    bson_lookup_doc (arguments, "filter", &filter);
-   mongoc_collection_remove (collection, MONGOC_REMOVE_NONE, &filter,
-                             NULL, NULL);
+   mongoc_collection_remove (
+      collection, MONGOC_REMOVE_NONE, &filter, NULL, NULL);
 }
 
 
 static void
-test_delete_one (mongoc_collection_t *collection,
-                 const bson_t        *arguments)
+test_delete_one (mongoc_collection_t *collection, const bson_t *arguments)
 {
    bson_t filter;
 
    bson_lookup_doc (arguments, "filter", &filter);
-   mongoc_collection_remove (collection, MONGOC_REMOVE_SINGLE_REMOVE, &filter,
-                             NULL, NULL);
+   mongoc_collection_remove (
+      collection, MONGOC_REMOVE_SINGLE_REMOVE, &filter, NULL, NULL);
 }
 
 
 static void
-test_insert_many (mongoc_collection_t *collection,
-                  const bson_t        *arguments)
+test_insert_many (mongoc_collection_t *collection, const bson_t *arguments)
 {
    bool ordered;
    mongoc_bulk_operation_t *bulk;
@@ -628,21 +638,20 @@ test_insert_many (mongoc_collection_t *collection,
 
 
 static void
-test_insert_one (mongoc_collection_t *collection,
-                 const bson_t        *arguments)
+test_insert_one (mongoc_collection_t *collection, const bson_t *arguments)
 {
    bson_t document;
 
    bson_lookup_doc (arguments, "document", &document);
-   mongoc_collection_insert (collection, MONGOC_INSERT_NONE, &document,
-                             NULL, NULL);
+   mongoc_collection_insert (
+      collection, MONGOC_INSERT_NONE, &document, NULL, NULL);
 }
 
 
 static void
 test_update (mongoc_collection_t *collection,
-             const bson_t        *arguments,
-             bool                 multi)
+             const bson_t *arguments,
+             bool multi)
 {
    bson_t filter;
    bson_t update;
@@ -664,24 +673,21 @@ test_update (mongoc_collection_t *collection,
 
 
 static void
-test_update_many (mongoc_collection_t *collection,
-                  const bson_t        *arguments)
+test_update_many (mongoc_collection_t *collection, const bson_t *arguments)
 {
    test_update (collection, arguments, true);
 }
 
 
 static void
-test_update_one (mongoc_collection_t *collection,
-                 const bson_t        *arguments)
+test_update_one (mongoc_collection_t *collection, const bson_t *arguments)
 {
    test_update (collection, arguments, false);
 }
 
 
 static void
-one_test (mongoc_collection_t *collection,
-          bson_t              *test)
+one_test (mongoc_collection_t *collection, bson_t *test)
 {
    context_t context;
    const char *description;
@@ -783,9 +789,8 @@ test_command_monitoring_cb (bson_t *scenario)
 
    while (bson_iter_next (&tests_iter)) {
       client = test_framework_client_new ();
-      collection = mongoc_client_get_collection (client,
-                                                 db_name,
-                                                 collection_name);
+      collection =
+         mongoc_client_get_collection (client, db_name, collection_name);
 
       insert_data (collection, scenario);
       bson_iter_bson (&tests_iter, &test_op);
@@ -831,7 +836,7 @@ test_get_error (void)
    mongoc_apm_callbacks_t *callbacks;
    future_t *future;
    request_t *request;
-   bson_error_t error = { 0 };
+   bson_error_t error = {0};
 
    server = mock_server_with_autoismaster (0);
    mock_server_run (server);
@@ -840,11 +845,10 @@ test_get_error (void)
    callbacks = mongoc_apm_callbacks_new ();
    mongoc_apm_set_command_failed_cb (callbacks, test_get_error_failed_cb);
    mongoc_client_set_apm_callbacks (client, callbacks, (void *) &error);
-   future = future_client_command_simple (client, "db",
-                                          tmp_bson ("{'foo': 1}"),
-                                          NULL, NULL, NULL);
-   request = mock_server_receives_command (server, "db", MONGOC_QUERY_SLAVE_OK,
-                                           "{'foo': 1}");
+   future = future_client_command_simple (
+      client, "db", tmp_bson ("{'foo': 1}"), NULL, NULL, NULL);
+   request = mock_server_receives_command (
+      server, "db", MONGOC_QUERY_SLAVE_OK, "{'foo': 1}");
    mock_server_replies_simple (request,
                                "{'ok': 0, 'errmsg': 'foo', 'code': 42}");
    ASSERT (!future_get_bool (future));
@@ -869,8 +873,8 @@ insert_200_docs (mongoc_collection_t *collection)
    /* insert 200 docs so we have a couple batches */
    doc = tmp_bson (NULL);
    for (i = 0; i < 200; i++) {
-      r = mongoc_collection_insert (collection, MONGOC_INSERT_NONE, doc, NULL,
-                                    &error);
+      r = mongoc_collection_insert (
+         collection, MONGOC_INSERT_NONE, doc, NULL, &error);
 
       ASSERT_OR_PRINT (r, error);
    }
@@ -944,14 +948,15 @@ test_change_callbacks (void *ctx)
    ASSERT_CMPINT (incremented, ==, 200);
 
    mongoc_client_set_apm_callbacks (client, dec_callbacks, &decremented);
-   cursor = mongoc_collection_aggregate (collection, MONGOC_QUERY_NONE,
-                                         tmp_bson (NULL), NULL, NULL);
+   cursor = mongoc_collection_aggregate (
+      collection, MONGOC_QUERY_NONE, tmp_bson (NULL), NULL, NULL);
 
    ASSERT (mongoc_cursor_next (cursor, &b));
    ASSERT_CMPINT (decremented, ==, -1);
 
    mongoc_client_set_apm_callbacks (client, inc_callbacks, &incremented);
-   while (mongoc_cursor_next (cursor, &b)) { }
+   while (mongoc_cursor_next (cursor, &b)) {
+   }
    ASSERT_OR_PRINT (!mongoc_cursor_error (cursor, &error), error);
    ASSERT_CMPINT (incremented, ==, 201);
 
@@ -978,6 +983,7 @@ test_reset_callbacks (void *ctx)
    bson_t *cmd;
    bson_t cmd_reply;
    bson_error_t error;
+   mongoc_server_description_t *sd;
    mongoc_cursor_t *cursor;
    const bson_t *b;
 
@@ -994,8 +1000,18 @@ test_reset_callbacks (void *ctx)
    cmd = tmp_bson ("{'aggregate': '%s', 'pipeline': [], 'cursor': {}}",
                    collection->collection);
 
-   r = mongoc_client_command_simple (client, "test", cmd, NULL, &cmd_reply,
-                                     &error);
+   sd =
+      mongoc_client_select_server (client, true /* for writes */, NULL, &error);
+   ASSERT_OR_PRINT (sd, error);
+
+   r = mongoc_client_read_command_with_opts (
+      client,
+      "test",
+      cmd,
+      NULL,
+      tmp_bson ("{'serverId': %d}", sd->id),
+      &cmd_reply,
+      &error);
 
    ASSERT_OR_PRINT (r, error);
    ASSERT_CMPINT (incremented, ==, 1);
@@ -1003,18 +1019,20 @@ test_reset_callbacks (void *ctx)
    /* reset callbacks */
    mongoc_client_set_apm_callbacks (client, NULL, NULL);
    /* destroys cmd_reply */
-   cursor = mongoc_cursor_new_from_command_reply (client, &cmd_reply, 1);
+   cursor = mongoc_cursor_new_from_command_reply (client, &cmd_reply, sd->id);
    ASSERT (mongoc_cursor_next (cursor, &b));
-   ASSERT_CMPINT (incremented, ==, 1);  /* same value as before */
+   ASSERT_CMPINT (incremented, ==, 1); /* same value as before */
 
    mongoc_client_set_apm_callbacks (client, dec_callbacks, &decremented);
-   while (mongoc_cursor_next (cursor, &b)) { }
+   while (mongoc_cursor_next (cursor, &b)) {
+   }
    ASSERT_OR_PRINT (!mongoc_cursor_error (cursor, &error), error);
    ASSERT_CMPINT (decremented, ==, -1);
 
    mongoc_collection_drop (collection, NULL);
 
    mongoc_cursor_destroy (cursor);
+   mongoc_server_description_destroy (sd);
    mongoc_collection_destroy (collection);
    mongoc_client_destroy (client);
    mongoc_apm_callbacks_destroy (inc_callbacks);
@@ -1046,13 +1064,13 @@ _test_set_callbacks (bool pooled)
 
    if (pooled) {
       pool = test_framework_client_pool_new ();
-      ASSERT (mongoc_client_pool_set_apm_callbacks (pool, callbacks,
-                                                    (void *) &n_calls));
+      ASSERT (mongoc_client_pool_set_apm_callbacks (
+         pool, callbacks, (void *) &n_calls));
       client = mongoc_client_pool_pop (pool);
    } else {
       client = test_framework_client_new ();
-      ASSERT (mongoc_client_set_apm_callbacks (client, callbacks,
-                                               (void *) &n_calls));
+      ASSERT (mongoc_client_set_apm_callbacks (
+         client, callbacks, (void *) &n_calls));
    }
 
    ASSERT_OR_PRINT (mongoc_client_get_server_status (client, NULL, &b, &error),
@@ -1062,15 +1080,15 @@ _test_set_callbacks (bool pooled)
    capture_logs (true);
 
    if (pooled) {
-      ASSERT (!mongoc_client_pool_set_apm_callbacks (pool, NULL,
-                                                     (void*) &n_calls));
+      ASSERT (
+         !mongoc_client_pool_set_apm_callbacks (pool, NULL, (void *) &n_calls));
       ASSERT_CAPTURED_LOG ("mongoc_client_pool_set_apm_callbacks",
                            MONGOC_LOG_LEVEL_ERROR,
                            "Can only set callbacks once");
 
       clear_captured_logs ();
-      ASSERT (!mongoc_client_set_apm_callbacks (client, NULL,
-                                                (void *) &n_calls));
+      ASSERT (
+         !mongoc_client_set_apm_callbacks (client, NULL, (void *) &n_calls));
       ASSERT_CAPTURED_LOG ("mongoc_client_pool_set_apm_callbacks",
                            MONGOC_LOG_LEVEL_ERROR,
                            "Cannot set callbacks on a pooled client");
@@ -1111,14 +1129,13 @@ typedef struct {
 } ids_t;
 
 
-typedef struct
-{
+typedef struct {
    mongoc_array_t started_ids;
    mongoc_array_t succeeded_ids;
    mongoc_array_t failed_ids;
-   int            started_calls;
-   int            succeeded_calls;
-   int            failed_calls;
+   int started_calls;
+   int succeeded_calls;
+   int failed_calls;
 } op_id_test_t;
 
 
@@ -1193,13 +1210,13 @@ test_op_id_failed_cb (const mongoc_apm_command_failed_t *event)
 
 
 #define REQUEST_ID(_event_type, _index) \
-    _mongoc_array_index (&test._event_type ## _ids, ids_t, _index).request_id
+   _mongoc_array_index (&test._event_type##_ids, ids_t, _index).request_id
 
 #define OP_ID(_event_type, _index) \
-    _mongoc_array_index (&test._event_type ## _ids, ids_t, _index).op_id
+   _mongoc_array_index (&test._event_type##_ids, ids_t, _index).op_id
 
 static void
-_test_bulk_operation_id (bool pooled)
+_test_bulk_operation_id (bool pooled, bool use_bulk_operation_new)
 {
    mongoc_client_t *client;
    mongoc_client_pool_t *pool = NULL;
@@ -1219,22 +1236,33 @@ _test_bulk_operation_id (bool pooled)
 
    if (pooled) {
       pool = test_framework_client_pool_new ();
-      ASSERT (mongoc_client_pool_set_apm_callbacks (pool, callbacks,
-                                                    (void *) &test));
+      ASSERT (mongoc_client_pool_set_apm_callbacks (
+         pool, callbacks, (void *) &test));
       client = mongoc_client_pool_pop (pool);
    } else {
       client = test_framework_client_new ();
-      ASSERT (mongoc_client_set_apm_callbacks (client, callbacks,
-                                               (void *) &test));
+      ASSERT (
+         mongoc_client_set_apm_callbacks (client, callbacks, (void *) &test));
    }
 
    collection = get_test_collection (client, "test_bulk_operation_id");
-   bulk = mongoc_collection_create_bulk_operation (collection, false, NULL);
+   if (use_bulk_operation_new) {
+      bulk = mongoc_bulk_operation_new (false);
+      mongoc_bulk_operation_set_client (bulk, client);
+      mongoc_bulk_operation_set_database (bulk, collection->db);
+      mongoc_bulk_operation_set_collection (bulk, collection->collection);
+   } else {
+      bulk = mongoc_collection_create_bulk_operation (collection, false, NULL);
+   }
+
    mongoc_bulk_operation_insert (bulk, tmp_bson ("{'_id': 1}"));
-   mongoc_bulk_operation_update_one (bulk, tmp_bson ("{'_id': 1}"),
-                                     tmp_bson ("{'$set': {'x': 1}}"), false);
+   mongoc_bulk_operation_update_one (
+      bulk, tmp_bson ("{'_id': 1}"), tmp_bson ("{'$set': {'x': 1}}"), false);
    mongoc_bulk_operation_remove (bulk, tmp_bson ("{}"));
 
+   /* ensure we monitor with bulk->operation_id, not cluster->operation_id */
+   client->cluster.operation_id = 42;
+
    /* write errors don't trigger failed events, so we only test success */
    ASSERT_OR_PRINT (mongoc_bulk_operation_execute (bulk, NULL, &error), error);
    ASSERT_CMPINT (test.started_calls, ==, 3);
@@ -1252,9 +1280,10 @@ _test_bulk_operation_id (bool pooled)
    ASSERT_CMPINT64 (REQUEST_ID (succeeded, 0), !=, REQUEST_ID (succeeded, 2));
    ASSERT_CMPINT64 (REQUEST_ID (succeeded, 1), !=, REQUEST_ID (succeeded, 2));
 
-   /* operation ids all the same */
-   op_id = OP_ID (started, 0);
+   /* events' operation ids all equal bulk->operation_id */
+   op_id = bulk->operation_id;
    ASSERT_CMPINT64 (op_id, !=, (int64_t) 0);
+   ASSERT_CMPINT64 (op_id, ==, OP_ID (started, 0));
    ASSERT_CMPINT64 (op_id, ==, OP_ID (started, 1));
    ASSERT_CMPINT64 (op_id, ==, OP_ID (started, 2));
    ASSERT_CMPINT64 (op_id, ==, OP_ID (succeeded, 0));
@@ -1277,16 +1306,30 @@ _test_bulk_operation_id (bool pooled)
 
 
 static void
-test_bulk_operation_id_single (void)
+test_collection_bulk_op_single (void)
 {
-   _test_bulk_operation_id (false);
+   _test_bulk_operation_id (false, false);
 }
 
 
 static void
-test_bulk_operation_id_pooled (void)
+test_collection_bulk_op_pooled (void)
 {
-   _test_bulk_operation_id (true);
+   _test_bulk_operation_id (true, false);
+}
+
+
+static void
+test_bulk_op_single (void)
+{
+   _test_bulk_operation_id (false, true);
+}
+
+
+static void
+test_bulk_op_pooled (void)
+{
+   _test_bulk_operation_id (true, true);
 }
 
 
@@ -1317,23 +1360,27 @@ _test_query_operation_id (bool pooled, bool use_cmd)
 
    if (pooled) {
       pool = mongoc_client_pool_new (mock_server_get_uri (server));
-      ASSERT (mongoc_client_pool_set_apm_callbacks (pool, callbacks,
-                                                    (void *) &test));
+      ASSERT (mongoc_client_pool_set_apm_callbacks (
+         pool, callbacks, (void *) &test));
       client = mongoc_client_pool_pop (pool);
    } else {
       client = mongoc_client_new_from_uri (mock_server_get_uri (server));
-      ASSERT (mongoc_client_set_apm_callbacks (client, callbacks,
-                                               (void *) &test));
+      ASSERT (
+         mongoc_client_set_apm_callbacks (client, callbacks, (void *) &test));
    }
 
    collection = mongoc_client_get_collection (client, "db", "collection");
-   cursor = mongoc_collection_find (collection, MONGOC_QUERY_NONE, 0, 0, 1,
-                                    tmp_bson ("{}"), NULL, NULL);
+   cursor = mongoc_collection_find (
+      collection, MONGOC_QUERY_NONE, 0, 0, 1, tmp_bson ("{}"), NULL, NULL);
 
    future = future_cursor_next (cursor, &doc);
    request = mock_server_receives_request (server);
-   mock_server_replies_to_find (request, MONGOC_QUERY_SLAVE_OK,
-                                123 /* cursor id */, 1, "db.collection", "{}",
+   mock_server_replies_to_find (request,
+                                MONGOC_QUERY_SLAVE_OK,
+                                123 /* cursor id */,
+                                1,
+                                "db.collection",
+                                "{}",
                                 use_cmd);
 
    ASSERT (future_get_bool (future));
@@ -1346,10 +1393,14 @@ _test_query_operation_id (bool pooled, bool use_cmd)
    future = future_cursor_next (cursor, &doc);
    request = mock_server_receives_request (server);
    if (use_cmd) {
-      mock_server_replies_simple (request, 
+      mock_server_replies_simple (request,
                                   "{'ok': 0, 'code': 42, 'errmsg': 'bad!'}");
    } else {
-      mock_server_replies (request, MONGOC_REPLY_QUERY_FAILURE, 123, 0, 0,
+      mock_server_replies (request,
+                           MONGOC_REPLY_QUERY_FAILURE,
+                           123,
+                           0,
+                           0,
                            "{'$err': 'uh oh', 'code': 4321}");
    }
 
@@ -1421,12 +1472,12 @@ test_query_operation_id_pooled_op_query (void)
 
 
 typedef struct {
-   int     started_calls;
-   int     succeeded_calls;
-   int     failed_calls;
-   char    db[100];
-   char    cmd_name[100];
-   bson_t  cmd;
+   int started_calls;
+   int succeeded_calls;
+   int failed_calls;
+   char db[100];
+   char cmd_name[100];
+   bson_t cmd;
 } cmd_test_t;
 
 
@@ -1488,8 +1539,7 @@ cmd_failed_cb (const mongoc_apm_command_failed_t *event)
 
 
 static void
-set_cmd_test_callbacks (mongoc_client_t *client,
-                        void            *context)
+set_cmd_test_callbacks (mongoc_client_t *client, void *context)
 {
    mongoc_apm_callbacks_t *callbacks;
 
@@ -1513,12 +1563,19 @@ test_client_cmd (void)
    cmd_test_init (&test);
    client = test_framework_client_new ();
    set_cmd_test_callbacks (client, (void *) &test);
-   cursor = mongoc_client_command (client, "admin", MONGOC_QUERY_SLAVE_OK, 0, 0,
-                                   0, tmp_bson ("{'ismaster': 1}"), NULL, NULL);
+   cursor = mongoc_client_command (client,
+                                   "admin",
+                                   MONGOC_QUERY_SLAVE_OK,
+                                   0,
+                                   0,
+                                   0,
+                                   tmp_bson ("{'ping': 1}"),
+                                   NULL,
+                                   NULL);
 
    ASSERT (mongoc_cursor_next (cursor, &reply));
-   ASSERT_CMPSTR (test.cmd_name, "ismaster");
-   ASSERT_MATCH (&test.cmd, "{'ismaster': 1}");
+   ASSERT_CMPSTR (test.cmd_name, "ping");
+   ASSERT_MATCH (&test.cmd, "{'ping': 1}");
    ASSERT_CMPSTR (test.db, "admin");
    ASSERT_CMPINT (1, ==, test.started_calls);
    ASSERT_CMPINT (1, ==, test.succeeded_calls);
@@ -1528,8 +1585,15 @@ test_client_cmd (void)
    mongoc_cursor_destroy (cursor);
 
    cmd_test_init (&test);
-   cursor = mongoc_client_command (client, "admin", MONGOC_QUERY_SLAVE_OK, 0, 0,
-                                   0, tmp_bson ("{'foo': 1}"), NULL, NULL);
+   cursor = mongoc_client_command (client,
+                                   "admin",
+                                   MONGOC_QUERY_SLAVE_OK,
+                                   0,
+                                   0,
+                                   0,
+                                   tmp_bson ("{'foo': 1}"),
+                                   NULL,
+                                   NULL);
 
    ASSERT (!mongoc_cursor_next (cursor, &reply));
    ASSERT_CMPSTR (test.cmd_name, "foo");
@@ -1557,11 +1621,11 @@ test_client_cmd_simple (void)
    client = test_framework_client_new ();
    set_cmd_test_callbacks (client, (void *) &test);
    r = mongoc_client_command_simple (
-      client, "admin", tmp_bson ("{'ismaster': 1}"), NULL, NULL, &error);
+      client, "admin", tmp_bson ("{'ping': 1}"), NULL, NULL, &error);
 
    ASSERT_OR_PRINT (r, error);
-   ASSERT_CMPSTR (test.cmd_name, "ismaster");
-   ASSERT_MATCH (&test.cmd, "{'ismaster': 1}");
+   ASSERT_CMPSTR (test.cmd_name, "ping");
+   ASSERT_MATCH (&test.cmd, "{'ping': 1}");
    ASSERT_CMPSTR (test.db, "admin");
    ASSERT_CMPINT (1, ==, test.started_calls);
    ASSERT_CMPINT (1, ==, test.succeeded_calls);
@@ -1585,6 +1649,62 @@ test_client_cmd_simple (void)
 }
 
 
+static void
+test_client_cmd_op_ids (void)
+{
+   op_id_test_t test;
+   mongoc_client_t *client;
+   mongoc_apm_callbacks_t *callbacks;
+   bool r;
+   bson_error_t error;
+   int64_t op_id;
+
+   op_id_test_init (&test);
+
+   callbacks = mongoc_apm_callbacks_new ();
+   mongoc_apm_set_command_started_cb (callbacks, test_op_id_started_cb);
+   mongoc_apm_set_command_succeeded_cb (callbacks, test_op_id_succeeded_cb);
+   mongoc_apm_set_command_failed_cb (callbacks, test_op_id_failed_cb);
+
+   client = test_framework_client_new ();
+   mongoc_client_set_apm_callbacks (client, callbacks, (void *) &test);
+
+   r = mongoc_client_command_simple (
+      client, "admin", tmp_bson ("{'ping': 1}"), NULL, NULL, &error);
+
+   ASSERT_OR_PRINT (r, error);
+   ASSERT_CMPINT (1, ==, test.started_calls);
+   ASSERT_CMPINT (1, ==, test.succeeded_calls);
+   ASSERT_CMPINT (0, ==, test.failed_calls);
+   ASSERT_CMPINT64 (REQUEST_ID (started, 0), ==, REQUEST_ID (succeeded, 0));
+   ASSERT_CMPINT64 (OP_ID (started, 0), ==, OP_ID (succeeded, 0));
+   op_id = OP_ID (started, 0);
+   ASSERT_CMPINT64 (op_id, !=, (int64_t) 0);
+
+   op_id_test_cleanup (&test);
+   op_id_test_init (&test);
+
+   /* again. test that we use a new op_id. */
+   r = mongoc_client_command_simple (
+      client, "admin", tmp_bson ("{'ping': 1}"), NULL, NULL, &error);
+
+   ASSERT_OR_PRINT (r, error);
+   ASSERT_CMPINT (1, ==, test.started_calls);
+   ASSERT_CMPINT (1, ==, test.succeeded_calls);
+   ASSERT_CMPINT (0, ==, test.failed_calls);
+   ASSERT_CMPINT64 (REQUEST_ID (started, 0), ==, REQUEST_ID (succeeded, 0));
+   ASSERT_CMPINT64 (OP_ID (started, 0), ==, OP_ID (succeeded, 0));
+   ASSERT_CMPINT64 (OP_ID (started, 0), !=, (int64_t) 0);
+
+   /* new op_id */
+   ASSERT_CMPINT64 (OP_ID (started, 0), !=, op_id);
+
+   mongoc_client_destroy (client);
+   op_id_test_cleanup (&test);
+   mongoc_apm_callbacks_destroy (callbacks);
+}
+
+
 static void
 test_killcursors_deprecated (void)
 {
@@ -1598,7 +1718,7 @@ test_killcursors_deprecated (void)
 
    /* connect */
    r = mongoc_client_command_simple (
-      client, "admin", tmp_bson ("{'ismaster': 1}"), NULL, NULL, &error);
+      client, "admin", tmp_bson ("{'ping': 1}"), NULL, NULL, &error);
 
    ASSERT_OR_PRINT (r, error);
    set_cmd_test_callbacks (client, (void *) &test);
@@ -1619,34 +1739,61 @@ void
 test_command_monitoring_install (TestSuite *suite)
 {
    test_all_spec_tests (suite);
-   TestSuite_Add (suite, "/command_monitoring/get_error", test_get_error);
-   TestSuite_AddLive (suite, "/command_monitoring/set_callbacks/single",
-                  test_set_callbacks_single);
-   TestSuite_AddLive (suite, "/command_monitoring/set_callbacks/pooled",
-                  test_set_callbacks_pooled);
+   TestSuite_AddMockServerTest (
+      suite, "/command_monitoring/get_error", test_get_error);
+   TestSuite_AddLive (suite,
+                      "/command_monitoring/set_callbacks/single",
+                      test_set_callbacks_single);
+   TestSuite_AddLive (suite,
+                      "/command_monitoring/set_callbacks/pooled",
+                      test_set_callbacks_pooled);
    /* require aggregation cursor */
-   TestSuite_AddFull (suite, "/command_monitoring/set_callbacks/change",
-                      test_change_callbacks, NULL, NULL,
+   TestSuite_AddFull (suite,
+                      "/command_monitoring/set_callbacks/change",
+                      test_change_callbacks,
+                      NULL,
+                      NULL,
                       test_framework_skip_if_max_wire_version_less_than_1);
-   TestSuite_AddFull (suite, "/command_monitoring/set_callbacks/reset",
-                      test_reset_callbacks, NULL, NULL,
+   TestSuite_AddFull (suite,
+                      "/command_monitoring/set_callbacks/reset",
+                      test_reset_callbacks,
+                      NULL,
+                      NULL,
                       test_framework_skip_if_max_wire_version_less_than_1);
-   TestSuite_AddLive (suite, "/command_monitoring/operation_id/bulk/single",
-                  test_bulk_operation_id_single);
-   TestSuite_AddLive (suite, "/command_monitoring/operation_id/bulk/pooled",
-                  test_bulk_operation_id_pooled);
-   TestSuite_Add (suite, "/command_monitoring/operation_id/query/single/cmd",
-                  test_query_operation_id_single_cmd);
-   TestSuite_Add (suite, "/command_monitoring/operation_id/query/pooled/cmd",
-                  test_query_operation_id_pooled_cmd);
-   TestSuite_Add (suite, "/command_monitoring/operation_id/query/single/op_query",
-                  test_query_operation_id_single_op_query);
-   TestSuite_Add (suite, "/command_monitoring/operation_id/query/pooled/op_query",
-                  test_query_operation_id_pooled_op_query);
-   TestSuite_AddLive (suite, "/command_monitoring/client_cmd",
-                  test_client_cmd);
-   TestSuite_AddLive (suite, "/command_monitoring/client_cmd_simple",
-                  test_client_cmd_simple);
-   TestSuite_AddLive (suite, "/command_monitoring/killcursors_deprecated",
+   TestSuite_AddLive (suite,
+                      "/command_monitoring/operation_id/bulk/collection/single",
+                      test_collection_bulk_op_single);
+   TestSuite_AddLive (suite,
+                      "/command_monitoring/operation_id/bulk/collection/pooled",
+                      test_collection_bulk_op_pooled);
+   TestSuite_AddLive (suite,
+                      "/command_monitoring/operation_id/bulk/new/single",
+                      test_bulk_op_single);
+   TestSuite_AddLive (suite,
+                      "/command_monitoring/operation_id/bulk/new/pooled",
+                      test_bulk_op_pooled);
+   TestSuite_AddMockServerTest (
+      suite,
+      "/command_monitoring/operation_id/query/single/cmd",
+      test_query_operation_id_single_cmd);
+   TestSuite_AddMockServerTest (
+      suite,
+      "/command_monitoring/operation_id/query/pooled/cmd",
+      test_query_operation_id_pooled_cmd);
+   TestSuite_AddMockServerTest (
+      suite,
+      "/command_monitoring/operation_id/query/single/op_query",
+      test_query_operation_id_single_op_query);
+   TestSuite_AddMockServerTest (
+      suite,
+      "/command_monitoring/operation_id/query/pooled/op_query",
+      test_query_operation_id_pooled_op_query);
+   TestSuite_AddLive (suite, "/command_monitoring/client_cmd", test_client_cmd);
+   TestSuite_AddLive (
+      suite, "/command_monitoring/client_cmd_simple", test_client_cmd_simple);
+   TestSuite_AddLive (
+      suite, "/command_monitoring/client_cmd/op_ids", test_client_cmd_op_ids);
+   TestSuite_AddLive (suite,
+                      "/command_monitoring/killcursors_deprecated",
                       test_killcursors_deprecated);
 }
