@@ -50,18 +50,19 @@ restore_state (const struct log_state *state)
 
 
 struct log_func_data {
-   mongoc_log_level_t  log_level;
-   char               *log_domain;
-   char               *message;
+   mongoc_log_level_t log_level;
+   char *log_domain;
+   char *message;
 };
 
 
-void log_func (mongoc_log_level_t  log_level,
-               const char         *log_domain,
-               const char         *message,
-               void               *user_data)
+void
+log_func (mongoc_log_level_t log_level,
+          const char *log_domain,
+          const char *message,
+          void *user_data)
 {
-   struct log_func_data *data = (struct log_func_data *)user_data;
+   struct log_func_data *data = (struct log_func_data *) user_data;
 
    data->log_level = log_level;
    data->log_domain = bson_strdup (log_domain);
@@ -112,7 +113,8 @@ test_mongoc_log_null (void)
    restore_state (&old_state);
 }
 
-static int should_run_trace_tests (void)
+static int
+should_run_trace_tests (void)
 {
 #ifdef MONGOC_TRACE
    return 1;
@@ -120,9 +122,10 @@ static int should_run_trace_tests (void)
    return 0;
 #endif
 }
-static int should_not_run_trace_tests (void)
+static int
+should_not_run_trace_tests (void)
 {
-   return !should_run_trace_tests();
+   return !should_run_trace_tests ();
 }
 
 static void
@@ -135,18 +138,18 @@ test_mongoc_log_trace_enabled (void *context)
    mongoc_log_set_handler (log_func, &data);
 
    mongoc_log_trace_enable ();
-   TRACE("%s", "Conscript reporting!");
+   TRACE ("%s", "Conscript reporting!");
    ASSERT_CMPINT (data.log_level, ==, MONGOC_LOG_LEVEL_TRACE);
    ASSERT_CONTAINS (data.message, " Conscript reporting!");
    bson_free (data.log_domain);
    bson_free (data.message);
 
-   TRACE("%s", "Awaiting orders");
+   TRACE ("%s", "Awaiting orders");
    ASSERT_CMPINT (data.log_level, ==, MONGOC_LOG_LEVEL_TRACE);
    ASSERT_CONTAINS (data.message, "Awaiting orders");
 
    mongoc_log_trace_disable ();
-   TRACE("%s", "For the Union");
+   TRACE ("%s", "For the Union");
    ASSERT_CMPINT (data.log_level, ==, MONGOC_LOG_LEVEL_TRACE);
    ASSERT_CONTAINS (data.message, "Awaiting orders");
    bson_free (data.log_domain);
@@ -154,7 +157,7 @@ test_mongoc_log_trace_enabled (void *context)
 
 
    mongoc_log_trace_enable ();
-   TRACE("%s", "For home country");
+   TRACE ("%s", "For home country");
    ASSERT_CMPINT (data.log_level, ==, MONGOC_LOG_LEVEL_TRACE);
    ASSERT_CONTAINS (data.message, "For home country");
 
@@ -168,13 +171,13 @@ static void
 test_mongoc_log_trace_disabled (void *context)
 {
    struct log_state old_state;
-   struct log_func_data data = {(mongoc_log_level_t)-1, 0, NULL};
+   struct log_func_data data = {(mongoc_log_level_t) -1, 0, NULL};
 
    save_state (&old_state);
    mongoc_log_set_handler (log_func, &data);
 
-   TRACE("%s", "Conscript reporting!");
-   ASSERT_CMPINT (data.log_level, ==, (mongoc_log_level_t)-1);
+   TRACE ("%s", "Conscript reporting!");
+   ASSERT_CMPINT (data.log_level, ==, (mongoc_log_level_t) -1);
 
    restore_state (&old_state);
 }
@@ -183,7 +186,17 @@ void
 test_log_install (TestSuite *suite)
 {
    TestSuite_Add (suite, "/Log/basic", test_mongoc_log_handler);
-   TestSuite_AddFull (suite, "/Log/trace/enabled", test_mongoc_log_trace_enabled, NULL, NULL, should_run_trace_tests);
-   TestSuite_AddFull (suite, "/Log/trace/disabled", test_mongoc_log_trace_disabled, NULL, NULL, should_not_run_trace_tests);
+   TestSuite_AddFull (suite,
+                      "/Log/trace/enabled",
+                      test_mongoc_log_trace_enabled,
+                      NULL,
+                      NULL,
+                      should_run_trace_tests);
+   TestSuite_AddFull (suite,
+                      "/Log/trace/disabled",
+                      test_mongoc_log_trace_disabled,
+                      NULL,
+                      NULL,
+                      should_not_run_trace_tests);
    TestSuite_Add (suite, "/Log/null", test_mongoc_log_null);
 }
